@@ -61,6 +61,7 @@
 #include "comdeepiniminterface.h"
 #include "dbusutils.h"
 #include "config.h"
+#include "player.h"
 DWIDGET_USE_NAMESPACE
 
 const QString s_PropertyViewname = "viewname";
@@ -84,11 +85,8 @@ MainFrame::MainFrame()
     this->setWindowTitle(tr("Music"));
 
     m_titlebarwidget = new TitlebarWidget(this);
-//    m_searchResult = new SearchResult(this);
-//    m_titlebarwidget->setResultWidget(m_searchResult);
 
     m_titlebar = new DTitlebar(this);
-    m_titlebar->setFixedHeight(50);
     m_titlebar->setTitle(tr("Music"));
     m_titlebar->setIcon(QIcon::fromTheme("deepin-music"));    //titlebar->setCustomWidget(titlebarwidget, Qt::AlignLeft, false);
 
@@ -98,13 +96,18 @@ MainFrame::MainFrame()
     AC_SET_OBJECT_NAME(m_backBtn, AC_titleBarLeft);
     AC_SET_ACCESSIBLE_NAME(m_backBtn, AC_titleBarLeft);
     m_backBtn->setVisible(false);
-    m_backBtn->setFixedSize(QSize(36, 36));
 
     m_addMusicBtn = new DIconButton(DStyle::SP_IncreaseElement, this);
     m_addMusicBtn->setToolTip(tr("Add music"));
     AC_SET_OBJECT_NAME(m_addMusicBtn, AC_titleBarAddMusic);
     AC_SET_ACCESSIBLE_NAME(m_addMusicBtn, AC_titleBarAddMusic);
+
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    slotSizeModeChanged(DGuiApplicationHelper::instance()->sizeMode());
+#else
+    m_backBtn->setFixedSize(QSize(36, 36));
     m_addMusicBtn->setFixedSize(QSize(36, 36));
+#endif
 
     m_selectStr = tr("Select");
     m_selectAllStr = tr("Select All");
@@ -115,7 +118,6 @@ MainFrame::MainFrame()
     m_backBtn->setIcon(QIcon::fromTheme("left_arrow"));
     m_titlebar->addWidget(m_backBtn, Qt::AlignLeft);
     m_titlebar->addWidget(m_addMusicBtn, Qt::AlignRight);
-    m_titlebar->resize(width(), 50);
 
     // 返回按钮点击
     connect(m_backBtn, &DPushButton::clicked,
@@ -156,6 +158,7 @@ MainFrame::MainFrame()
         show();
         raise();
         activateWindow();
+        this->setWindowState((this->windowState() & ~Qt::WindowMinimized) | Qt::WindowActive);
     });
 
     connect(CommonService::getInstance(), &CommonService::signalSwitchToView, this, &MainFrame::slotViewChanged);
@@ -172,6 +175,14 @@ MainFrame::MainFrame()
             m_importWidget->slotFileImportProcessing(itemMetas);
         }
     });
+    connect(Player::getInstance(), &Player::signalMediaMetaChanged,
+            this, [=](MediaMeta meta) {
+        this->setWindowTitle(meta.localPath);
+    });
+
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    connect(DGuiApplicationHelper::instance(),&DGuiApplicationHelper::sizeModeChanged,this, &MainFrame::slotSizeModeChanged);
+#endif
 
     if (CommonService::getInstance()->isTabletEnvironment()) {
         QDBusConnection connection = QDBusConnection::sessionBus();
@@ -234,6 +245,10 @@ void MainFrame::initUI(bool showLoading)
     connect(m_musicLyricWidget, &MusicLyricWidget::signalAutoHidden,
             m_footerWidget, &FooterWidget::slotLyricAutoHidden);
 
+    connect(m_musicLyricWidget, &MusicLyricWidget::signalAutoHidden, m_footerWidget, [=](){
+        m_isLyricShow = false;
+    });
+
     connect(CommonService::getInstance(), &CommonService::signalCdaImportFinished,
             this, &MainFrame::slotCdaImportFinished);
 
@@ -628,6 +643,40 @@ void MainFrame::slotActiveChanged(bool isActive)
     }
 }
 
+#ifdef DTKWIDGET_CLASS_DSizeMode
+void MainFrame::slotSizeModeChanged(DGuiApplicationHelper::SizeMode sizeMode)
+{
+    if (sizeMode == DGuiApplicationHelper::SizeMode::CompactMode) {
+        m_backBtn->setFixedSize(QSize(25, 25));
+        m_addMusicBtn->setFixedSize(QSize(25, 25));
+        if (m_footerWidget) {
+            m_footerWidget->setGeometry(FooterWidget::Margin, height() - FooterWidget::CompactHeight - FooterWidget::Margin,
+                                        width() - FooterWidget::Margin * 2, FooterWidget::CompactHeight);
+        }
+    } else {
+        if (m_footerWidget) {
+            m_footerWidget->setGeometry(FooterWidget::Margin, height() - FooterWidget::Height - FooterWidget::Margin,
+                                        width() - FooterWidget::Margin * 2, FooterWidget::Height);
+        }
+        m_backBtn->setFixedSize(QSize(36, 36));
+        m_addMusicBtn->setFixedSize(QSize(36, 36));
+    }
+
+    if (m_musicStatckedWidget) {
+        m_musicStatckedWidget->setGeometry(0, titlebar()->height(), width(), height() - m_footerWidget->height() - titlebar()->height());
+    }
+
+    if (m_musicContentWidget) {
+        m_musicContentWidget->setGeometry(0, titlebar()->height(), width(), height() - m_footerWidget->height() - titlebar()->height());
+    }
+
+    if (m_musicLyricWidget) {
+        m_musicLyricWidget->setGeometry(0, titlebar()->height(), width(), height() - titlebar()->height());
+    }
+    update();
+}
+#endif
+
 void MainFrame::slotSearchEditFoucusIn()
 {
     m_titlebarwidget->slotSearchEditFoucusIn();
@@ -651,6 +700,8 @@ void MainFrame::slotLyricClicked()
         //搜索页面使能
         m_titlebarwidget->setEnabled(true);
     }
+
+    m_isLyricShow = true;
 }
 
 void MainFrame::slotDBImportFinished(QString hash, int successCount)
@@ -1046,8 +1097,18 @@ void MainFrame::showEvent(QShowEvent *event)
     this->setFocus();
 
     if (m_footerWidget) {
+#ifdef DTKWIDGET_CLASS_DSizeMode
+        if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::SizeMode::CompactMode) {
+            m_footerWidget->setGeometry(FooterWidget::Margin, height() - FooterWidget::CompactHeight - FooterWidget::Margin,
+                                        width() - FooterWidget::Margin * 2, FooterWidget::CompactHeight);
+        } else {
+            m_footerWidget->setGeometry(FooterWidget::Margin, height() - FooterWidget::Height - FooterWidget::Margin,
+                                        width() - FooterWidget::Margin * 2, FooterWidget::Height);
+        }
+#else
         m_footerWidget->setGeometry(FooterWidget::Margin, height() - FooterWidget::Height - FooterWidget::Margin,
                                     width() - FooterWidget::Margin * 2, FooterWidget::Height);
+#endif
     }
 
     if (m_importWidget) {
@@ -1080,8 +1141,18 @@ void MainFrame::resizeEvent(QResizeEvent *e)
     }
 
     if (m_footerWidget) {
+#ifdef DTKWIDGET_CLASS_DSizeMode
+        if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::SizeMode::CompactMode) {
+            m_footerWidget->setGeometry(FooterWidget::Margin, height() - FooterWidget::CompactHeight - FooterWidget::Margin,
+                                        width() - FooterWidget::Margin * 2, FooterWidget::CompactHeight);
+        } else {
+            m_footerWidget->setGeometry(FooterWidget::Margin, height() - FooterWidget::Height - FooterWidget::Margin,
+                                        width() - FooterWidget::Margin * 2, FooterWidget::Height);
+        }
+#else
         m_footerWidget->setGeometry(FooterWidget::Margin, height() - FooterWidget::Height - FooterWidget::Margin,
                                     width() - FooterWidget::Margin * 2, FooterWidget::Height);
+#endif
     }
 
     if (m_musicStatckedWidget) {
@@ -1195,6 +1266,32 @@ void MainFrame::hideEvent(QHideEvent *event)
     m_geometryBa = saveGeometry();
 }
 
+void MainFrame::paintEvent(QPaintEvent* e)
+{
+    QPainter painter(this);
+    QRect rect(0, height() - FooterWidget::Height,
+               220, FooterWidget::Height);
+
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::SizeMode::CompactMode) {
+        rect.setY(height() - FooterWidget::CompactHeight);
+        rect.setHeight(FooterWidget::CompactHeight);
+    }
+#endif
+
+    QBrush brush(QColor("#FFFFFF"));
+    if (m_isLyricShow) {
+        brush.setColor(Qt::transparent);
+    } else {
+        if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::DarkType) {
+            brush.setColor("#232323");
+        }
+    }
+
+    painter.fillRect(rect, brush);
+    DMainWindow::paintEvent(e);
+}
+
 void MainFrame::playQueueAnimation()
 {
     if (m_playQueueWidget == nullptr) {
